# gy-redis

## pip package
```
pip install gy-redis -U
```

## build package
First change the version or related information of setup.py

```
python setup.py sdist
```

## input tocken
```
twine upload dist/*
```

